@@ -39,6 +39,7 @@ gnome_rr_output_info_init (GnomeRROutputInfo *self)
 
     self->priv->name = NULL;
     self->priv->on = FALSE;
+    self->priv->rotation = GNOME_RR_ROTATION_0;
     self->priv->display_name = NULL;
 }
 
@@ -49,6 +50,9 @@ gnome_rr_output_info_finalize (GObject *gobject)
 
     g_free (self->priv->name);
     g_free (self->priv->display_name);
+    g_free (self->priv->product);
+    g_free (self->priv->serial);
+    g_free (self->priv->vendor);
 
     G_OBJECT_CLASS (gnome_rr_output_info_parent_class)->finalize (gobject);
 }
@@ -247,3 +251,18 @@ int gnome_rr_output_info_get_preferred_height (GnomeRROutputInfo *self)
 
     return self->priv->pref_height;
 }
+
+gboolean gnome_rr_output_info_get_underscanning (GnomeRROutputInfo *self)
+{
+    g_return_val_if_fail (GNOME_IS_RR_OUTPUT_INFO (self), FALSE);
+
+    return self->priv->underscanning;
+}
+
+void gnome_rr_output_info_set_underscanning (GnomeRROutputInfo *self,
+                                             gboolean underscanning)
+{
+    g_return_if_fail (GNOME_IS_RR_OUTPUT_INFO (self));
+
+    self->priv->underscanning = underscanning;
+}
