@@ -130,8 +130,6 @@ void            gnome_rr_screen_get_ranges         (GnomeRRScreen         *scree
 						    int                   *min_height,
 						    int                   *max_height);
 
-GnomeRRMode   **gnome_rr_screen_create_clone_modes (GnomeRRScreen *screen);
-
 gboolean        gnome_rr_screen_get_dpms_mode      (GnomeRRScreen        *screen,
                                                     GnomeRRDpmsMode       *mode,
                                                     GError               **error);
@@ -173,6 +171,7 @@ GnomeRRMode *   gnome_rr_output_get_preferred_mode (GnomeRROutput         *outpu
 gboolean        gnome_rr_output_supports_mode      (GnomeRROutput         *output,
 						    GnomeRRMode           *mode);
 gboolean        gnome_rr_output_get_is_primary     (GnomeRROutput         *output);
+gboolean        gnome_rr_output_get_is_underscanning (GnomeRROutput       *output);
 
 /* GnomeRRMode */
 guint32         gnome_rr_mode_get_id               (GnomeRRMode           *mode);
